use v6.d;
use Test;

use FileSystem::Parent;

my $append  = 'lib';

my $found   = scan-up :$append;
ok $found,   'scan-up $append';

put '# Found', $found;

ok $found ~~ / lib $/, "Found: '$append'";

done-testing;
