use v6.d;
use Test;

use FileSystem::Parent;

my $verbose = %*ENV< VERBOSE > ?? True !! False;

# $pass0 && $pass1 are Seq.

my $pass0  = scan-up;
ok $pass0,  "scan-up = $pass0";

my $pass1  = scan-up :from( $*PROGRAM-NAME );
ok $pass1,  "scan-up :from( $*PROGRAM-NAME ) = $pass1";

ok $pass0.eager ~~ $pass1.eager, 'Bin and $*Program-Name return same list.';

done-testing;
